@@ -13,6 +13,7 @@ test.data <- data.frame(ids = c(1, 2, 3), strs = c('a', 'b', 'c'))
 
 test_that('Proper dplyr src is set up by srcr()', {
     has_sqlite()
+    withr::local_options(lifecycle_verbosity = "quiet")
     expect_is((mysrc <- get.src()), 'src_sql')
     expect_is((test.table <- copy_to(mysrc, test.data, name = 'test_table')),
               'tbl')
@@ -24,5 +25,6 @@ test_that('Proper DBI connection is set up by srcr()', {
     expect_is((mysrc <- get.con()), 'SQLiteConnection')
     expect_is((test.table <- copy_to(mysrc, test.data, name = 'test_table')),
               'tbl')
-    expect_equal(collect(tbl(mysrc,'test_table')), test.table)
+    expect_equal(tbl(mysrc,'test_table'), test.table)
+    if (any(class(mysrc) == 'SQLiteConnection')) DBI::dbDisconnect(mysrc)
 })
